@@ -21,8 +21,7 @@ import sge
 
 class Object(object):
 
-    """Class for game objects.
-
+    """
     This class is used for game objects, such as the player, enemies,
     bullets, and the HUD.  Generally, each type of object has its own
     subclass of :class:`sge.Object`.
@@ -256,15 +255,14 @@ class Object(object):
        A :class:`sge.Color` object representing the color to blend with
        the sprite.  Set to :const:`None` for no color blending.
 
-    .. attribute:: id
+    .. attribute:: alarms
 
-       The unique identifier for this object.  (Read-only)
-
-    .. attribute:: alive
-
-       Whether or not the object is alive.  An object is considered to
-       be "alive" from the time it is first added to a room to the time
-       it is destroyed.  (Read-only)
+       A dictionary containing the alarms of the object.  Each value
+       decreases by 1 each frame (adjusted for delta timing if it is
+       enabled).  When a value is at or below 0,
+       :meth:`sge.Object.event_alarm` is executed with ``alarm_id`` set
+       to the respective key, and the item is deleted from this
+       dictionary.
 
     .. attribute:: mask
 
@@ -300,34 +298,29 @@ class Object(object):
 
        The vertical location of the mask in the room.  (Read-only)
 
+    .. attribute:: rd
+
+       Reserved dictionary for internal use by the SGE.  (Read-only)
     """
 
-    def __init__(self, x, y, z=0, ID=None, sprite=None, visible=True,
-                 active=True, checks_collisions=True, tangible=True,
-                 bbox_x=None, bbox_y=None, bbox_width=None, bbox_height=None,
+    def __init__(self, x, y, z=0, sprite=None, visible=True, active=True,
+                 checks_collisions=True, tangible=True, bbox_x=None,
+                 bbox_y=None, bbox_width=None, bbox_height=None,
                  regulate_origin=False, collision_ellipse=False,
                  collision_precise=False, xvelocity=0, yvelocity=0,
                  image_index=0, image_origin_x=None, image_origin_y=None,
                  image_fps=None, image_xscale=1, image_yscale=1,
                  image_rotation=0, image_alpha=255, image_blend=None):
-        """Constructor method.
-
-        Arguments:
-
-        - ``ID`` -- The value to set :attr:`id` to.  If set to
-          :const:`None`, ``fname`` minus the extension will be used,
-          modified by the SGE if it is already the unique identifier of
-          another music object.
-
-        All other arugments set the respective initial attributes of the
-        object.  See the documentation for :class:`sge.Object` for
-        more information.
-
+        """
+        Arugments set the respective initial attributes of the object.
+        See the documentation for :class:`sge.Object` for more
+        information.
         """
         # TODO
 
     def collision(self, other=None, x=None, y=None):
-        """Return a list of objects colliding with this object.
+        """
+        Return a list of objects colliding with this object.
 
         Arguments:
 
@@ -335,9 +328,7 @@ class Object(object):
           the following:
 
           - A :class:`sge.Object` object.
-          - The unique identifier of a :class:`sge.Object` object.
-          - A list of :class:`sge.Object` objects and/or unique
-            identifiers of :class:`sge.Object` objects.
+          - A list of :class:`sge.Object` objects.
           - A class derived from :class:`sge.Object`.
           - :const:`None`: Check for collisions with all objects.
 
@@ -347,64 +338,43 @@ class Object(object):
         - ``y`` -- The vertical position to pretend this object is at
           for the purpose of the collision detection.  If set to
           :const:`None`, :attr:`y` will be used.
-
-        """
-        # TODO
-
-    def set_alarm(self, alarm_id, value):
-        """Set an alarm.
-
-        After this method is called, ``value`` will reduce by 1 each
-        frame (adjusted for delta timing if it is enabled) until it
-        reaches 0, at which point :meth:`sge.Object.event_alarm`
-        will be executed with ``alarm_id``.
-
-        See the documentation for :meth:`sge.Game.set_alarm` for more
-        information.
-
-        """
-        # TODO
-
-    def get_alarm(self, alarm_id):
-        """Return the value of an alarm.
-
-        See the documentation for :meth:`sge.Game.get_alarm` for more
-        information.
-
         """
         # TODO
 
     def destroy(self):
-        """Destroy the object.
-
-        This removes the object from all rooms in the game, deletes its
-        reference in :attr:`sge.game.objects`, and marks it as "dead".
-
         """
-        # TODO
+        Remove the object from the current room.  ``foo.destroy()`` is
+        identical to ``sge.game.current_room.remove(foo)``.
+        """
+        sge.game.current_room.remove(self)
 
     def event_create(self):
-        """Create event.
-
-        Called right after the object is created.  It is always called
-        after any room start events occurring at the same time.
+        """
+        Called in the following cases:
 
+        - Right after the object is added to the current room.
+        - Right after a room starts for the first time after the object
+          was added to it, if and only if the object was added to the
+          room while it was not the current room.  In this case, this
+          event is called after the respective room start event.
         """
         pass
 
     def event_destroy(self):
-        """Destroy event.
+        """
+        Called right after the object is removed from the current room.
 
-        Called right after the object is destroyed.
+        .. note::
 
+           If the object is removed from a room while it is not the
+           current room, this method will not be called.
         """
         pass
 
     def event_begin_step(self, time_passed, delta_mult):
-        """Begin step event.
-
-        This event is executed each frame before automatic updates to
-        objects (such as the effects of the speed variables).
+        """
+        Called each frame before automatic updates to objects (such as
+        the effects of the speed variables).
 
         See the documentation for :meth:`sge.Game.event_step` for more
         information.
@@ -412,149 +382,118 @@ class Object(object):
         .. note::
 
            Automatic updates, the only occurances between this event and
-           :meth:`sge.Object.event_step`, do not occur, so there
-           is no need for an "inactive" variant of this event.  Use
-           :meth:`sge.Object.event_inactive_step` instead.
-
+           :meth:`sge.Object.event_step`, do not occur when the object
+           is inactive, so there is no need for an "inactive" variant of
+           this event.  Use :meth:`sge.Object.event_inactive_step`
+           instead.
         """
         pass
 
     def event_step(self, time_passed, delta_mult):
-        """Step event.
-
-        This event is executed each frame after automatic updates to
-        objects (such as the effects of the speed variables), but before
-        collision events.
+        """
+        Called each frame after automatic updates to objects (such as
+        the effects of the speed variables), but before collision
+        events.
 
         See the documentation for :meth:`sge.Game.event_step` for more
         information.
-
         """
         pass
 
     def event_end_step(self, time_passed, delta_mult):
-        """Step event.
-
-        This event is executed each frame after automatic updates to
-        objects (such as the effects of the speed variables), but before
-        collision events.
+        """
+        Called each frame after automatic updates to objects (such as
+        the effects of the speed variables), but before collision
+        events.
 
         See the documentation for :meth:`sge.Game.event_step` for more
         information.
-
         """
         pass
 
     def event_alarm(self, alarm_id):
-        """Alarm event.
-
-        See the documentation for :meth:`sge.Game.event_alarm` for more
+        """
+        See the documentation for :meth:`sge.Object.alarms` for more
         information.
-
         """
         pass
 
     def event_animation_end(self):
-        """Animation End event.
-
-        Called when an animation cycle ends.
-
-        """
+        """Called when an animation cycle ends."""
         pass
 
     def event_key_press(self, key, char):
-        """Key press event.
-
+        """
         See the documentation for :class:`sge.input.KeyPress` for more
         information.
-
         """
         pass
 
     def event_key_release(self, key):
-        """Key release event.
-
+        """
         See the documentation for :class:`sge.input.KeyRelease` for more
         information.
-
         """
         pass
 
     def event_mouse_move(self, x, y):
-        """Mouse move event.
-
+        """
         See the documentation for :class:`sge.input.MouseMove` for more
         information.
-
         """
         pass
 
     def event_mouse_button_press(self, button):
-        """Mouse button press event.
-
+        """
         See the documentation for :class:`sge.input.MouseButtonPress`
         for more information.
-
         """
         pass
 
     def event_mouse_button_release(self, button):
-        """Mouse button release event.
-
+        """
         See the documentation for :class:`sge.input.MouseButtonRelease`
         for more information.
-
         """
         pass
 
     def event_joystick_axis_move(self, js_name, js_id, axis, value):
-        """Joystick axis move event.
-
+        """
         See the documentation for :class:`sge.input.JoystickAxisMove`
         for more information.
-
         """
         pass
 
     def event_joystick_hat_move(self, js_name, js_id, hat, x, y):
-        """Joystick hat move event.
-
+        """
         See the documentation for :class:`sge.input.JoystickHatMove` for
         more information.
-
         """
         pass
 
     def event_joystick_trackball_move(self, js_name, js_id, ball, x, y):
-        """Joystick trackball move event.
-
+        """
         See the documentation for
         :class:`sge.input.JoystickTrackballMove` for more information.
-
         """
         pass
 
     def event_joystick_button_press(self, js_name, js_id, button):
-        """Joystick button press event.
-
+        """
         See the documentation for :class:`sge.input.JoystickButtonPress`
         for more information.
-
         """
         pass
 
     def event_joystick_button_release(self, js_name, js_id, button):
-        """Joystick button release event.
-
+        """
         See the documentation for
         :class:`sge.input.JoystickButtonRelease` for more information.
-
         """
         pass
 
     def event_update_position(self, delta_mult):
-        """Update position event.
-
+        """
         Called when it's time to update the position of the object.
         This method handles this functionality, so defining this will
         override the default behavior and allow you to handle the speed
@@ -567,14 +506,12 @@ class Object(object):
 
         See the documentation for :meth:`sge.Game.event_step` for more
         information.
-
         """
         self.x += self.xvelocity * delta_mult
         self.y += self.yvelocity * delta_mult
 
     def event_collision(self, other):
-        """Default collision event.
-
+        """
         Called when another object collides with this object and none of
         the directional collision events are appropriate.  In
         particular, this is called if the collision was already
@@ -584,13 +521,11 @@ class Object(object):
         Arguments:
 
         - ``other`` -- The other object which was collided with.
-
         """
         pass
 
     def event_collision_left(self, other):
-        """Left collision event.
-
+        """
         Called when another object collides with this object's left
         side.
 
@@ -600,13 +535,11 @@ class Object(object):
 
         By default, this method simply calls
         :meth:`sge.Object.event_collision`.
-
         """
         self.event_collision(other)
 
     def event_collision_right(self, other):
-        """Right collision event.
-
+        """
         Called when another object collides with this object's right
         side.
 
@@ -616,13 +549,11 @@ class Object(object):
 
         By default, this method simply calls
         :meth:`sge.Object.event_collision`.
-
         """
         self.event_collision(other)
 
     def event_collision_top(self, other):
-        """Top collision event.
-
+        """
         Called when another object collides with this object's top side.
 
         Arguments:
@@ -631,13 +562,11 @@ class Object(object):
 
         By default, this method simply calls
         :meth:`sge.Object.event_collision`.
-
         """
         self.event_collision(other)
 
     def event_collision_bottom(self, other):
-        """Bottom collision event.
-
+        """
         Called when another object collides with this object's bottom
         side.
 
@@ -647,94 +576,78 @@ class Object(object):
 
         By default, this method simply calls
         :meth:`sge.Object.event_collision`.
-
         """
         self.event_collision(other)
 
     def event_inactive_step(self, time_passed, delta_mult):
-        """Step event when this object is inactive.
-
+        """
         See the documentation for :meth:`sge.Object.event_step`
         for more information.  The object is considered to be inactive
         when :attr:`active` is :const:`False`.
-
         """
         pass
 
     def event_inactive_end_step(self, time_passed, delta_mult):
-        """End step event when this object is inactive.
-
+        """
         See the documentation for
         :meth:`sge.Object.event_end_step` for more information.
         The object is considered to be inactive when :attr:`active` is
         :const:`False`.
-
         """
         pass
 
     def event_inactive_key_press(self, key, char):
-        """Key press event when this object is inactive.
-
+        """
         The object is considered to be inactive when :attr:`active` is
         :const:`False`.
 
         See the documentation for :class:`sge.input.KeyPress` for more
         information.
-
         """
         pass
 
     def event_inactive_key_release(self, key):
-        """Key release event when this object is inactive.
-
+        """
         The object is considered to be inactive when :attr:`active` is
         :const:`False`.
 
         See the documentation for :class:`sge.input.KeyRelease` for more
         information.
-
         """
         pass
 
     def event_inactive_mouse_move(self, x, y):
-        """Mouse move event when this object is inactive.
-
+        """
         The object is considered to be inactive when :attr:`active` is
         :const:`False`.
 
         See the documentation for :class:`sge.input.MouseMove` for more
         information.
-
         """
         pass
 
     def event_inactive_mouse_button_press(self, button):
-        """Mouse button press event when this object is inactive.
-
+        """
         The object is considered to be inactive when :attr:`active` is
         :const:`False`.
 
         See the documentation for :class:`sge.input.MouseButtonPress`
         for more information.
-
         """
         pass
 
     def event_inactive_mouse_button_release(self, button):
-        """Mouse button release event when this object is inactive.
-
+        """
         The object is considered to be inactive when :attr:`active` is
         :const:`False`.
 
         See the documentation for :class:`sge.input.MouseButtonRelease`
         for more information.
-
         """
         pass
 
     def event_inactive_joystick_axis_move(self, js_name, js_id, axis, value):
-        """Joystick axis move event when this object is inactive.
-
+        """
         The object is considered to be inactive when :attr:`active` is
         :const:`False`.
 
@@ -745,65 +658,54 @@ class Object(object):
         pass
 
     def event_inactive_joystick_hat_move(self, js_name, js_id, hat, x, y):
-        """Joystick hat move event when this object is inactive.
-
+        """
         The object is considered to be inactive when :attr:`active` is
         :const:`False`.
 
         See the documentation for :class:`sge.input.JoystickHatMove` for
         more information.
-
         """
         pass
 
     def event_inactive_joystick_trackball_move(self, js_name, js_id, ball, x, y):
-        """Joystick trackball move event when this object is inactive.
-
+        """
         The object is considered to be inactive when :attr:`active` is
         :const:`False`.
 
         See the documentation for
         :class:`sge.input.JoystickTrackballMove` for more information.
-
         """
         pass
 
     def event_inactive_joystick_button_press(self, js_name, js_id, button):
-        """Joystick button press event when this object is inactive.
-
+        """
         The object is considered to be inactive when :attr:`active` is
         :const:`False`.
 
         See the documentation for :class:`sge.input.JoystickButtonPress`
         for more information.
-
         """
         pass
 
     def event_inactive_joystick_button_release(self, js_name, js_id, button):
-        """Joystick button release event when this object is inactive.
-
+        """
         The object is considered to be inactive when :attr:`active` is
         :const:`False`.
 
         See the documentation for
         :class:`sge.input.JoystickButtonRelease` for more information.
-
         """
         pass
 
     def event_paused_key_press(self, key, char):
-        """Key press event when paused.
-
+        """
         See the documentation for :class:`sge.input.KeyPress` for more
         information.
-
         """
         pass
 
     def event_paused_key_release(self, key):
-        """Key release event when paused.
-
+        """
         See the documentation for :class:`sge.input.KeyRelease` for more
         information.
 
@@ -811,80 +713,65 @@ class Object(object):
         pass
 
     def event_paused_mouse_move(self, x, y):
-        """Mouse move event when paused.
-
+        """
         See the documentation for :class:`sge.input.MouseMove` for more
         information.
-
         """
         pass
 
     def event_paused_mouse_button_press(self, button):
-        """Mouse button press event when paused.
-
+        """
         See the documentation for :class:`sge.input.MouseButtonPress`
         for more information.
-
         """
         pass
 
     def event_paused_mouse_button_release(self, button):
-        """Mouse button release event when paused.
-
+        """
         See the documentation for :class:`sge.input.MouseButtonRelease`
         for more information.
-
         """
         pass
 
     def event_paused_joystick_axis_move(self, js_name, js_id, axis, value):
-        """Joystick axis move event when paused.
-
+        """
         See the documentation for :class:`sge.input.JoystickAxisMove`
         for more information.
-
         """
         pass
 
     def event_paused_joystick_hat_move(self, js_name, js_id, hat, x, y):
-        """Joystick hat move event when paused.
-
+        """
         See the documentation for :class:`sge.input.JoystickHatMove` for
         more information.
-
         """
         pass
 
     def event_paused_joystick_trackball_move(self, js_name, js_id, ball, x, y):
-        """Joystick trackball move event when paused.
-
+        """
         See the documentation for
         :class:`sge.input.JoystickTrackballMove` for more information.
-
         """
         pass
 
     def event_paused_joystick_button_press(self, js_name, js_id, button):
-        """Joystick button press event when paused.
-
+        """
         See the documentation for :class:`sge.input.JoystickButtonPress`
         for more information.
-
         """
         pass
 
     def event_paused_joystick_button_release(self, js_name, js_id, button):
-        """Joystick button release event when paused.
-
+        """
         See the documentation for
         :class:`sge.input.JoystickButtonRelease` for more information.
-
         """
         pass
 
     @classmethod
     def create(cls, *args, **kwargs):
-        """Create an object of this class in the current room it.
+        """
+        Create an object of this class and add it to the current room.
 
         ``args`` and ``kwargs`` are passed to the constructor method of
         ``cls`` as arguments.  Calling
@@ -892,7 +779,6 @@ class Object(object):
 
             obj = cls(*args, **kwargs)
             sge.game.current_room.add(obj)
-
         """
         obj = cls(*args, **kwargs)
         sge.game.current_room.add(obj)
