@@ -117,16 +117,15 @@ class Sprite(object):
        Reserved dictionary for internal use by the SGE.  (Read-only)
     """
 
-    def __init__(self, name=None, width=None, height=None, transparent=True,
-                 origin_x=0, origin_y=0, fps=60, bbox_x=None, bbox_y=None,
-                 bbox_width=None, bbox_height=None):
+    def __init__(self, name=None, directory="", width=None, height=None,
+                 transparent=True, origin_x=0, origin_y=0, fps=60, bbox_x=None,
+                 bbox_y=None, bbox_width=None, bbox_height=None):
         """
         Arguments:
 
         - ``name`` -- The base name of the image files, used to find all
-          individual image files that make up the sprite's animation in
-          the paths specified in :data:`sge.image_directories`.  One of
-          the following rules will be used to find the images:
+          individual image files that make up the sprite's animation`.
+          One of the following rules will be used to find the images:
 
           - The base name plus a valid image extension.  If this rule is
             used, the image will be loaded as a single-frame sprite.
@@ -150,6 +149,8 @@ class Sprite(object):
           If none of the above rules can be used, :exc:`IOError` is
           raised.
 
+        - ``directory`` -- The directory to search for image files in.
+
         All other arguments set the respective initial attributes of the
         sprite.  See the documentation for :class:`Sprite` for more
         information.
@@ -509,7 +510,7 @@ class Sprite(object):
         # TODO
 
     @classmethod
-    def from_tileset(cls, name, x=0, y=0, columns=1, rows=1, xsep=0, ysep=0,
+    def from_tileset(cls, fname, x=0, y=0, columns=1, rows=1, xsep=0, ysep=0,
                      width=1, height=1, origin_x=0, origin_y=0,
                      transparent=True, fps=0, bbox_x=None, bbox_y=None,
                      bbox_width=None, bbox_height=None):
@@ -518,9 +519,8 @@ class Sprite(object):
 
         Arguments:
 
-        - ``name`` -- The base name of the image file containing the
-          tileset, not including the file extension, to be found in one
-          of the paths specified in :data:`sge.image_directories`.
+        - ``fname`` -- The path to the image file containing the
+          tileset.
         - ``x`` -- The horizontal location relative to the image of the
           top-leftmost tile in the tileset.
         - ``y`` -- The vertical location relative to the image of the
